Iterio Commons
==============

The name may not be very specific, but it's totally adequate. It's the common stuff that we at
Iterio use in our modern Python codebases.

If the library will get too big or messy we'll split it into more focused libraries.

Development
-----------

Just look at the Makefiles - names of the targets should be pretty self-explanatory.
